import { Channel, ClientFactory } from 'nice-grpc';
import { EventEmitter } from 'events';
import { DispatcherClient as PbDispatcherClient, DispatcherClient } from '../../protoc/dispatcher';
import { ClientConfig } from '../hatchet-client/client-config';
import { Logger } from '../../util/logger';
import { Api } from '../rest';
import { GrpcPooledListener } from './child-listener-client';
export declare enum RunEventType {
    STEP_RUN_EVENT_TYPE_STARTED = "STEP_RUN_EVENT_TYPE_STARTED",
    STEP_RUN_EVENT_TYPE_COMPLETED = "STEP_RUN_EVENT_TYPE_COMPLETED",
    STEP_RUN_EVENT_TYPE_FAILED = "STEP_RUN_EVENT_TYPE_FAILED",
    STEP_RUN_EVENT_TYPE_CANCELLED = "STEP_RUN_EVENT_TYPE_CANCELLED",
    STEP_RUN_EVENT_TYPE_TIMED_OUT = "STEP_RUN_EVENT_TYPE_TIMED_OUT",
    STEP_RUN_EVENT_TYPE_STREAM = "STEP_RUN_EVENT_TYPE_STREAM",
    WORKFLOW_RUN_EVENT_TYPE_STARTED = "WORKFLOW_RUN_EVENT_TYPE_STARTED",
    WORKFLOW_RUN_EVENT_TYPE_COMPLETED = "WORKFLOW_RUN_EVENT_TYPE_COMPLETED",
    WORKFLOW_RUN_EVENT_TYPE_FAILED = "WORKFLOW_RUN_EVENT_TYPE_FAILED",
    WORKFLOW_RUN_EVENT_TYPE_CANCELLED = "WORKFLOW_RUN_EVENT_TYPE_CANCELLED",
    WORKFLOW_RUN_EVENT_TYPE_TIMED_OUT = "WORKFLOW_RUN_EVENT_TYPE_TIMED_OUT"
}
export interface StepRunEvent {
    type: RunEventType;
    payload: string;
}
export declare class RunEventListener {
    client: DispatcherClient;
    q: Array<StepRunEvent>;
    eventEmitter: EventEmitter<[never]>;
    pollInterval: any;
    constructor(workflowRunid: string, client: DispatcherClient);
    emit(event: StepRunEvent): void;
    listen(workflowRunId: string): Promise<void>;
    retrySubscribe(workflowRunId: string): Promise<AsyncIterable<import("../../protoc/dispatcher").WorkflowEvent>>;
    stream(): AsyncGenerator<StepRunEvent, void, unknown>;
}
export declare class ListenerClient {
    config: ClientConfig;
    client: PbDispatcherClient;
    logger: Logger;
    api: Api;
    pooledListener: GrpcPooledListener | undefined;
    constructor(config: ClientConfig, channel: Channel, factory: ClientFactory, api: Api);
    get(workflowRunId: string): import("./child-listener-client").Streamable;
    stream(workflowRunId: string): Promise<AsyncGenerator<StepRunEvent, void, unknown>>;
}
