import * as z from 'zod';
import { Action } from './clients/dispatcher/action-listener';
import { LogLevel } from './clients/event/event-client';
import { Logger } from './util/logger';
import { HatchetClient } from './clients/hatchet-client';
import WorkflowRunRef from './util/workflow-run-ref';
export declare const CreateRateLimitSchema: z.ZodObject<{
    key: z.ZodString;
    units: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    key: string;
    units: number;
}, {
    key: string;
    units: number;
}>;
export declare const CreateStepSchema: z.ZodObject<{
    name: z.ZodString;
    parents: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    timeout: z.ZodOptional<z.ZodString>;
    retries: z.ZodOptional<z.ZodNumber>;
    rate_limits: z.ZodOptional<z.ZodArray<z.ZodObject<{
        key: z.ZodString;
        units: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        key: string;
        units: number;
    }, {
        key: string;
        units: number;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    name: string;
    timeout?: string | undefined;
    parents?: string[] | undefined;
    retries?: number | undefined;
    rate_limits?: {
        key: string;
        units: number;
    }[] | undefined;
}, {
    name: string;
    timeout?: string | undefined;
    parents?: string[] | undefined;
    retries?: number | undefined;
    rate_limits?: {
        key: string;
        units: number;
    }[] | undefined;
}>;
export type JsonObject = {
    [Key in string]: JsonValue;
} & {
    [Key in string]?: JsonValue | undefined;
};
export type JsonArray = JsonValue[] | readonly JsonValue[];
export type JsonPrimitive = string | number | boolean | null;
export type JsonValue = JsonPrimitive | JsonObject | JsonArray;
export type NextStep = {
    [key: string]: JsonValue;
};
interface ContextData<T, K> {
    input: T;
    parents: Record<string, any>;
    triggered_by: string;
    user_data: K;
}
export declare class Context<T, K = {}> {
    data: ContextData<T, K>;
    input: T;
    controller: AbortController;
    action: Action;
    client: HatchetClient;
    overridesData: Record<string, any>;
    logger: Logger;
    spawnIndex: number;
    constructor(action: Action, client: HatchetClient);
    stepOutput(step: string): NextStep;
    triggeredByEvent(): boolean;
    workflowInput(): T;
    workflowName(): string;
    userData(): K;
    stepName(): string;
    workflowRunId(): string;
    retryCount(): number;
    playground(name: string, defaultValue?: string): string;
    log(message: string, level?: LogLevel): void;
    /**
     * Refreshes the timeout for the current step.
     * @param incrementBy - The interval by which to increment the timeout.
     *                     The interval should be specified in the format of '10s' for 10 seconds,
     *                     '1m' for 1 minute, or '1d' for 1 day.
     */
    refreshTimeout(incrementBy: string): Promise<void>;
    releaseSlot(): Promise<void>;
    putStream(data: string | Uint8Array): Promise<void>;
    spawnWorkflow<Q = JsonValue, P = JsonValue>(workflowName: string, input: Q, key?: string): WorkflowRunRef<P>;
}
export type StepRunFunction<T, K> = (ctx: Context<T, K>) => Promise<NextStep | void> | NextStep | void;
export interface CreateStep<T, K> extends z.infer<typeof CreateStepSchema> {
    run: StepRunFunction<T, K>;
}
export {};
